@@ -2,7 +2,9 @@
 
 source(system.file("testdata/lme-tst-funs.R", package="lme4", mustWork=TRUE))
 ##--> rSim.11()
+testLevel <- if (nzchar(s <- Sys.getenv("LME4_TEST_LEVEL"))) as.numeric(s) else 1
 
+if (testLevel>1) {
 set.seed(1)
 d1 <- rSim.11(10000, k=4)
 library(nlme)
@@ -16,3 +18,4 @@ fm.Bq <- update(fm.NM, control=lmerControl("bobyqa"))
 v.lmer <- VarCorr(fm.NM)[[1]][1,1]
 stopifnot(all.equal(v.lmer,19.55,tolerance=1e-3))
 ## was 19.5482 with old starting values (1), 19.5493 with new start algorithm
+} ## testLevel>1
