@@ -74,7 +74,7 @@ ggl2 <- glmer(y ~ x + (1|block), data=dgl, family=Gamma(link="log"))# true model
 stopifnot(
     all.equal(unlist(h.1.2[2,]),
               c(npar = 4, AIC = 34216.014, BIC = 34239.467, logLik = -17104.007,
-                deviance = 34208.014, Chisq = 2458.5792, Df = 1, `Pr(>Chisq)` = 0))
+                "-2*log(L)" = 34208.014, Chisq = 2458.5792, Df = 1, `Pr(>Chisq)` = 0))
 )
 ## "true" model :
 summary(ggl2)
